"""
Pynotio is designed to be a really simple Python wrapper around the official Notion API.

Ruslan Abkadirov [https://blog.ruslanabk.ru/]
rusabk@yandex.ru
# License: Apache License 2.0
"""

from .version import version

__author__ = 'Ruslan Abkadirov'
__version__ = version